.. _costs:

Costs
=====

Base
----

.. currentmodule:: skchange.costs.base

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    BaseCost

Costs
-----
.. currentmodule:: skchange.costs

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    EmpiricalDistributionCost
    GaussianCost
    L1Cost
    L2Cost
    LaplaceCost
    LinearRegressionCost
    LinearTrendCost
    MultivariateGaussianCost
    MultivariateTCost
    PoissonCost
